"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.Remote = void 0;
const vscode = __importStar(require("vscode"));
const authority_1 = require("./authority");
const sshConfig_1 = require("./sshConfig");
const cli_1 = require("./cli");
class Remote {
    constructor(ctx, storage, output) {
        this.ctx = ctx;
        this.storage = storage;
        this.output = output;
    }
    async setup(remoteAuthority) {
        const parts = (0, authority_1.parseRemoteAuthority)(remoteAuthority);
        if (!parts) {
            return;
        }
        this.output.appendLine(`Remote setup: ${parts.owner}/${parts.workspace} (agent=${parts.agent})`);
        const deployment = this.storage.getDeployment();
        if (!deployment) {
            vscode.window.showErrorMessage('Neural Inverse Cloud: Not logged in. Click the Desktop button from your cloud dashboard to connect.');
            return;
        }
        if (deployment.safeHostname !== parts.safeHostname) {
            this.output.appendLine(`Hostname mismatch: stored=${deployment.safeHostname}, authority=${parts.safeHostname}`);
        }
        const cliPath = await (0, cli_1.ensureCli)(this.ctx, deployment.url, this.output);
        if (!cliPath) {
            return;
        }
        await (0, sshConfig_1.writeSshConfig)(deployment, parts.owner, parts.workspace, parts.agent, cliPath, this.output);
    }
}
exports.Remote = Remote;
//# sourceMappingURL=remote.js.map